package com.brilliance.isc.funds.bo;

import com.brilliance.mda.runtime.mda.util.Decimals;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import lombok.Getter;
import lombok.Setter;


import java.math.BigDecimal;
import java.util.Date;
import static com.brilliance.mda.runtime.mda.Constants.NULLDATE;
import static com.brilliance.mda.runtime.mda.Constants.NULLSTR;


/**
* TABLE:fxd:
 *
 *
 * 1、 Reference：这笔结售汇业务的编号。在选择了售汇币种后可以通过Get Ref获取，或者在交易存盘时系统自动获取。
 * 2、Name：这笔结售汇业务的简要说明，系统根据交易要素自动赋值。
 * 3、Responsible User：这笔结汇业务的经办人，默认为登陆柜员，也可以通过点击“i”按钮更改成其他经办人。
 *     4 、Exchange Type：这笔结售汇业务的类型，本期默认为即期售汇。
 * 5、Purchase Amount：这笔结售汇业务的售汇币种及金额，根据业务实际情况输入，必输项。
 * 6、Domestic Amount：这笔结售汇业务的本币币种及金额，币种默认为人民币CNY，不可更改，金额由系统根据交易要素自动计算得出。
 * 7、Applicant：这笔结售汇业务的申请人，根据业务实际情况输入，必输项。
 * 8、Exchange Rate：这笔结售汇业务所使用的牌价，如果不需要资金部报价，则自动根据申请人的汇率优惠情况在原结售汇牌价基础上计算得出。
 * 9、Middle Rate：这笔结售汇业务所涉及的中间价，如果不需要资金部报价，则自动带出结汇币种的中间价。
 * 10、钞汇标志：这笔结售汇业务的钞汇标志，选项为现汇和现钞，默认为现汇，根据业务实际情况输入。
 * 11、Quote Ref.：本交易不适用。
 * 12、Treasury Dept. Ref.：本交易不适用。
 * 13、Open Date：这笔结售汇业务的成交日期，系统默认为当前日期，可以根据业务实际情况修改。
 * 14、Value Date：这笔结售汇业务的起息日，系统默认为成交日，可以根据业务实际情况修改。
 * 15、Settlement Date：本期不适用。
 * 16、Begin Date of Settle：本期不适用。
 * 17、Expiry Date of Settle：本期不适用。
 * 18、Foreign Cur. Account：这笔结售汇业务的外币的记账账号类型与记账账号，有LO客户往来账户、VT客户待核查账户、HA内部往来清算账户以及SP国际结算过渡账户4个选项，系统会根据账号类型自动带出相关账号，也可根据业务实际情况输入，必输项。
 * 19、Domestic Cur. Account：这笔结售汇业务的本币的记账账号类型与记账账号，有LO客户往来账户,HA内部往来清算账户以及SP国际结算过渡账户3个选项，系统会根据账号类型自动带出相关账号，也可根据业务实际情况输入，必输项。
 * 20、Exchange Party Type：这笔结售汇业务的申请人的主体类型，系统会根据静态数据的信息自动默认，也可根据业务实际情况输入，必输项。
 * 21、Exchange Title：这笔结售汇业务的类型，根据业务实际情况输入，必输项。
 * 22、Remark：这笔结售汇业务的备注信息。
*/

@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Fxd {



        //Internal Unique ID of Import L/C
        //@TDSetter(max=8)
        private String inr = NULLSTR;

        //Reference
        //@TDSetter(max=16)
        private String ownref = NULLSTR;

        //Externally Displayed Name to Identify the Contract
        //@TDSetter(max=40)
        private String nam = NULLSTR;

        //Date Foreign Exchange Opened/Issued
        @JsonFormat(pattern="yyyy-MM-dd",timezone="GMT+8")
       // @TDSetter
        private Date opndat = NULLDATE;

        //Responsible User
       // @TDSetter(max=8)
        private String ownusr = NULLSTR;

        //Foreign Exchange Type
       // @TDSetter(max=2)
        private String fxtyp = NULLSTR;

        //Rate
       // @TDSetter(scale=6)
        private  BigDecimal rat  = Decimals.ZERO_SCALE6;

        //Middle Rate
     //   @TDSetter(scale=6)
        private  BigDecimal midrat  = Decimals.ZERO_SCALE6;

        //Quote Reference
       // @TDSetter(max=16)
        private String quoref = NULLSTR;

        //Fund Department Reference
      //  @TDSetter(max=16)
        private String fudref = NULLSTR;

        //Value date
        @JsonFormat(pattern="yyyy-MM-dd",timezone="GMT+8")
      //  @TDSetter
        private Date valdat = NULLDATE;

        //Date of confirmation
        @JsonFormat(pattern="yyyy-MM-dd",timezone="GMT+8")
      //  @TDSetter
        private Date cnfdat = NULLDATE;

        //Settlement Date
        @JsonFormat(pattern="yyyy-MM-dd",timezone="GMT+8")
       // @TDSetter
        private Date setdat = NULLDATE;

        //Settlemt date from
        @JsonFormat(pattern="yyyy-MM-dd",timezone="GMT+8")
      //  @TDSetter
        private Date setdatfrm = NULLDATE;

        //Settlement date to
        @JsonFormat(pattern="yyyy-MM-dd",timezone="GMT+8")
       // @TDSetter
        private Date setdatto = NULLDATE;

        //Date of Closed
        @JsonFormat(pattern="yyyy-MM-dd",timezone="GMT+8")
        //@TDSetter
        private Date clsdat = NULLDATE;

        //Version
     //   @TDSetter(max=4)
        private String ver = NULLSTR;

        //Branch INR
      //  @TDSetter(max=8)
        private String branchinr = NULLSTR;

        //Branch INR
     //   @TDSetter(max=8)
        private String bchkeyinr = NULLSTR;

        //TRADE IN
       // @TDSetter(max=3)
        private String trdint = NULLSTR;

        //TRADE OUT
     //   @TDSetter(max=3)
        private String trdout = NULLSTR;

        //交易主体
     //   @TDSetter(max=2)
        private String trnman = NULLSTR;

        //Foreign Account
      //  @TDSetter(max=21)
        private String acc = NULLSTR;

        //CNY Account
      //  @TDSetter(max=21)
        private String acc2 = NULLSTR;

        //Clearing Department Responsible User
        //@TDSetter(max=8)
        private String usr = NULLSTR;

        //Disposition
      //  @TDSetter(max=2)
        private String dsp = NULLSTR;

        //Disposition
      //  @TDSetter(max=2)
        private String dsp2 = NULLSTR;

        //Cash cover percent
      //  @TDSetter(scale=2)
        private  BigDecimal cshpct  = Decimals.ZERO_SCALE2;

        //Rate
       //@TDSetter(scale=6)
        private  BigDecimal rat1  = Decimals.ZERO_SCALE6;

        //Account manager
     //   @TDSetter(max=8)
        private String accmng = NULLSTR;

        //客户经理部门
     //   @TDSetter(max=8)
        private String hdbch = NULLSTR;

        //Entity  KEY of Entry
        //@TDSetter(max=8)
        private String etyextkey = NULLSTR;


}